# `mics_library`
## A Python package to work with MICS data

`mics_library` provides functions to extract and process dataset from the Multiple Indicator Cluster Survey (MICS), from UNICEF.

For more info about MICS, see [here](https://mics.unicef.org), and [here](https://onlinelibrary.wiley.com/doi/full/10.1111/sifp.12103).

### Install
`pip install mics_library`

### Usage
Please see the Tutorial Jupyter notebooks on how to use `mics_library`


---
### Contacts:

Public GitLab repository: [TODO](TODO)

Developer: andrea.bizzego@unitn.it
